function logp = l_negative_binomial(bet, gam, data, x_pointer, ...
      z_pointer, y_pointer, intensity)
%  Evaluate the Negative Binomial model log predictive density
%
%  Inputs:
%  bet          Coefficients of x_t (C.JNwork x M.bet_count)
%  gam          Coefficients of z_t (C.JNwork x M.gam_count)
%  data         The data set for x_t, z_t and y_t (C.tlast x size(data,2))
%  x_pointer    Columns including x_t in the data
%  z_pointer    Columns including z_t in the data
%  y_pointer    Column including y_t in the data
%  intensity    Vector of current information intensity (C.tlast x 1)
%
%  Output:
%  logp         valuation of the log likelihood (C.JNwork  x 1)

tt   = find(intensity > 0);
n    = size(bet,1);
logp = u_allocate([n, 1]);

for i = 1:length(tt)
    t = tt(i);
    
    logmean = bet*data(t, x_pointer)';
    logoverdispersion = gam*data(t, z_pointer)';
    y = data(t, y_pointer);
 
    logp = logp + intensity(t)*(l_nbpdf(y, logmean, logoverdispersion));  
end

end