function logp = l_normal(bet, gam, data, x_pointer, z_pointer, ...
    y_pointer, intensity)
%  Evaluate the Normal model log predictive density
%
%  Inputs:
%  bet          Coefficients of x_t (C.JNwork x M.bet_count)
%  gam          Coefficients of z_t (C.JNwork x M.gam_count)
%  data         The data set for x_t, z_t and y_t (C.tlast x size(data,2))
%  x_pointer    Columns including x_t in the data
%  z_pointer    Columns including z_t in the data
%  y_pointer    Column including y_t in the data
%  intensity    Vector of current information intensity (C.tlast x 1)
%
%  Output:
%  logp         Evaluation of the log likelihood (C.JNwork  x 1)

tt   = find(intensity > 0);
logp = u_allocate([size(bet,1), 1]);

for i = 1:length(tt)
    t = tt(i);
    mu = bet*data(t, x_pointer)';
    logvary = gam*data(t, z_pointer)';
    logp = logp + intensity(t)*(log(2*pi) + logvary + ...
        ((data(t, y_pointer) - mu).^2)./exp(logvary))*(-0.5);
end

end