function logp = l_poisson(bet, data, x_pointer, y_pointer, intensity)
%  Evaluate the Poisson model log predictive density.
%  Invoking function must have mapped theta -> bet.
%  Inputs:
%  bet         Matrix of parameters (C.JNwork x C.parameters)
%  data        The data x_t and y_t (C.tlast x size(data,2)) 
%  x_pointer   Columns of data comprising x_t
%  y_pointer   Column of data comprising y_t
%  intensity   Vector of current information intensity (C.tlast x 1)
%
%  Output:
%  logp        Evaluation of the log likelihood (C.JNwork  x 1)

%  Programming note: The CUDA version of this function does not have to
%  do any mapping (u_collect_CUDA).
%  (As always the computation in *_CUDA is organized differently because
%  each row of theta is a thread.)

logp = u_allocate([size(bet,1), 1]);
tt = find(intensity > 0);

for i = 1:length(tt)
    t = tt(i);
    loglambda = bet*data(t, x_pointer)';
    logp = logp + ...
        intensity(t)*(data(t, y_pointer)*loglambda - exp(loglambda)...
        - gammaln(data(t, y_pointer)+1));
end

end