function y = l_poisssim(theta, x, method)
%  Simulate from the Poisson model using alternative values of the
%  parameters and the covariates.
%
%  Inputs:
%  theta   Parameter matrix, each row an alternative parameter vector 
%                                                                  (JN x k) 
%  x       Covariate matrix, each row an alternatve covariate vector 
%                                                                   (T x k)
%  method  = 1 for brute force (debug mode only); = 2 for C/CUDA 
%          mock-up; = 3 for Matlab code
%
%  Output:
%  y       y(j,t) is one simulation from the Poisson model using the
%          parameters in theta(j,:) and the covariate vector x(t,:) 
%                                                                  (JN x T)

[T, ~] = size(x);
JN = size(theta, 1);
y = u_allocate([JN, T]);

%  Brute force code
if method == 1
    for j = 1:JN
        for t = 1:T
            lambda = exp(theta(j,:)*x(t,:)');
            y(j,t) = poissrnd(lambda);
        end
    end
    
%  C/CUDA code
elseif method == 2
    for j = 1:JN
        lambda = exp(x*theta(j,:)');  % T x 1
        y(j,:) = poissrnd(lambda');
    end
    
%  Matlab code
else
    for t = 1:T
        lambda = exp(theta*x(t,:)');  % JN x 1
        y(:,t) = poissrnd(lambda);
    end
end
        
    
    