clear all;  close all;
addpath ../
global E
E.gpu = false;
T = 3;
nrep = 10000;
data = [[ones(T, 1), randn(T, 2)], randn(T, 1)];
xindex = [1, 2];
zindex = [1, 3];
yindex = 4;
theta = 10*[0.1, 0.1, -2, 0.1; -0.1, -0.1, -3, 0];
alphaindex = [1, 2];
betaindex = [3, 4];
intensity = ones(T,1);

JN = size(theta, 1);
T = size(data, 1);
JNT = JN*T;

y1 = zeros(JNT, nrep);
for irep = 1:nrep
    y1(:,irep) = reshape(l_normalsim(theta, betaindex, alphaindex, ...
        data, xindex, zindex, 1), JNT, 1);
end
mean1 = mean(y1, 2);
var1 = cov(y1');
disp('Mean and variance method 1');  disp([mean1, var1])

y2 = zeros(JNT, nrep);
for irep = 1:nrep
    y2(:,irep) = reshape(l_normalsim(theta, betaindex, alphaindex, ...
        data, xindex, zindex, 2), JNT, 1);
end
mean2 = mean(y2, 2);
var2 = cov(y2');
disp('Mean and variance method 2');  disp([mean1, var2])

y3 = zeros(JNT, nrep);
for irep = 1:nrep
    y3(:,irep) = reshape(l_normalsim(theta, betaindex, alphaindex, ...
        data, xindex, zindex, 3), JNT, 1);
end
mean3 = mean(y3, 2);
var3 = cov(y3');
disp('Mean and variance method 3');  disp([mean1, var3])

sd = sqrt(diag(0.5*(var1+var2)));
tstat = sqrt(nrep)*(mean1-mean2)./sd;
vdiff = sqrt(0.5*nrep)*diag(1./sd)*(var1 - var2)*diag(1./sd);
disp('Contrast 1 vs 2')
disp([tstat, vdiff])

sd = sqrt(diag(0.5*(var1+var3)));
tstat = sqrt(nrep)*(mean1-mean3)./sd;
vdiff = sqrt(0.5*nrep)*diag(1./sd)*(var1 - var3)*diag(1./sd);
disp('Contrast 1 vs 3')
disp([tstat, vdiff])

sd = sqrt(diag(0.5*(var2+var3)));
tstat = sqrt(nrep)*(mean2-mean3)./sd;
vdiff = sqrt(0.5*nrep)*diag(1./sd)*(var2 - var3)*diag(1./sd);
disp('Contrast 2 vs 3')
disp([tstat, vdiff])

disp('Consistency check, JN = 1, T = 1')
pdf = zeros(nrep, 1);
yy = zeros(nrep, 1);
for irep = 1:nrep
    yy(irep) = y1(1,irep);
    data1 = [data(1,1:3),yy(irep)];
    pdf(irep) = exp(l_normal(theta(1,:), betaindex, alphaindex, ...
    1, data1, xindex, zindex, yindex, 3));
end
u_pdfcheck(yy, pdf, true)

disp('Consistency check, j = 1, T = 3')
yy = zeros(nrep, 3);
for irep = 1:nrep
    yy(irep, :) = y1([1 3 5],irep)';
    data1 = [data(:,1:3),y1([1 3 5],irep)];
    pdf(irep) = exp(l_normal(theta(1,:), betaindex, alphaindex, ...
    intensity, data1, xindex, zindex, yindex, 3));
end
u_pdfcheck(yy, pdf, true)

disp('Consistency check, j = 2, T = 3')
yy = zeros(nrep, 3);
for irep = 1:nrep
    yy(irep, :) = y1([2 4 6],irep)';
    data1 = [data(:,1:3),y1([2 4 6],irep)];
    pdf(irep) = exp(l_normal(theta(2,:), betaindex, alphaindex, ...
    intensity, data1, xindex, zindex, yindex, 3));
end
u_pdfcheck(yy, pdf, true)