clear all;  close all
addpath ../
global E
E.gpu = false;
nrep = 10000;
T = 3;
x = [ones(T, 1), randn(T, 1)];
xindex = [1, 2];
yindex = 3;
theta = 0.1*[5 -0.2; 4 1];

JN = size(theta, 1);
T = size(x, 1);
y1 = zeros(JN, T, nrep);
for irep = 1:nrep
    y1(:,:,irep) = l_poisssim(theta, x, 1);
end
freq1 = zeros(JN, T, 5);
for i = 1:5
    freq1(:,:,i) = sum(y1==i-1,3)/nrep;
end

y2 = zeros(JN, T, nrep);
for irep = 1:nrep
    y2(:,:,irep) = l_poisssim(theta, x, 2);
end
freq2 = zeros(JN, T, 5);
for i = 1:5
    freq2(:,:,i) = sum(y2==i-1,3)/nrep;
end

y3 = zeros(JN, T, nrep);
for irep = 1:nrep
    y3(:,:,irep) = l_poisssim(theta, x, 3);
end
freq3 = zeros(JN, T, 5);
for i = 1:5
    freq3(:,:,i) = sum(y3==i-1,3)/nrep;
end

disp('Test mutual consistency of simulation methods')
freq = (freq1+freq2+freq3)/3;
for i = 1:5
    fprintf('Outcome = %d\n',i-1)
    fprintf('\n')
    f1 = squeeze(freq1(:,:,i));
    f2 = squeeze(freq2(:,:,i));
    f3 = squeeze(freq3(:,:,i));
    f = squeeze(freq(:,:,i));
    disp(100*f1)
    disp(100*f2)
    disp(100*f3)
    disp(sqrt(nrep)*(f1-f2)./sqrt(f.*(1-f)))
    disp(sqrt(nrep)*(f1-f3)./sqrt(f.*(1-f)))
    disp(sqrt(nrep)*(f2-f3)./sqrt(f.*(1-f)))
end

disp('Tests of consistency between l_poisson and l_poisspdf')
pf = zeros(JN,5);
phat = zeros(JN,5);
tstat = zeros(JN,5);
data = [x, zeros(T,1)];
for t = 1:3
    fprintf('Observation %d\n', t);  fprintf('\n')
    for i = 1:5
        data(t,3) = i-1;
        pf(:,i) = exp(l_poisson(theta, 1, data(t,:), [1, 2], 3, 3));
        phat(:,i) = squeeze(freq3(:,t,i));
    end
    tstat = sqrt(nrep)*(phat-pf)./sqrt(pf.*(1-pf));
    for j = 1:JN
        fprintf('Particle %d\n', j);  fprintf('\n')
        disp(100*pf(j,:));  disp(100*phat(j,:));  disp(tstat(j,:))
    end
end
        