function logp = m_message(theta, intensity)
%  This function sets up the evaluation of the log-likelihood by the
%  function l_mvnormal or l_mvnormal_CUDA
%
%  Inputs:
%  theta      Matrix of particles (C.JN x C.parameters).
%  intensity  Ignored because l_mvnormal uses the sufficient statistic
%             representation of the likelihood function.  
%             m_monitor sets M.F and M.T correctly, instead.
%
%  Output:
%  logp       Current information about theta.

global C M E

datawhole = strcmp(C.Cphase_method, 'data_whole');
if datawhole && ~u_compare(intensity, M.oldintensity)
    M.F = u_factor(M.data(intensity>0, :));
    M.oldintensity = intensity;
end
    
if M.easymap  % False indicates nonlinear transformations and E.gpu = true
    if E.gpu
        logp 		= u_allocate([size(theta,1), 1]);
        theta_ne 	= u_allocate([size(theta,1), ...
                      size(M.Alinc,2)+size(M.Blinc,2)+size(M.Hlinc,2)], ...
                      'default');

        logp = l_mvnormal_CUDA(theta, gpuArray(M.F), M.T, M.Amap, M.Alinc, 'A', ...
            M.Bmap, M.Blinc, 'B', M.Hmap, M.Hlinc, 'H', ...
	    M.A_tri, logp, theta_ne);
    else
        logp = l_mvnormal(theta, M.F, M.T, M.Amap, M.Alinc, 'A', ...
            M.Bmap, M.Blinc, 'B', M.Hmap, M.Hlinc, 'H', M.A_tri);
    end
else
    if E.gpu
        [A, Amap] = u_collectpart(theta, M.Amap, M.Alinc, 'A');
        [B, Bmap] = u_collectpart(theta, M.Bmap, M.Blinc, 'B');
        [H, Hmap] = u_collectpart(theta, M.Hmap, M.Hlinc, 'H');
        theta1 = [A, B, H];
        Bmap = ( Bmap + size(A,2)*(Bmap>0) );
        Hmap = ( Hmap + (size(A,2)+size(B,2))*(Hmap>0) );

        %  All Amap, Bmap, Hmap entries integers in [0, size(theta1,2)]
        theta_ne = u_allocate([size(theta,1), ...
                      size(M.Alinc,2)+size(M.Blinc,2)+size(M.Hlinc,2)], ...
                      'default');       
        logp = u_allocate([size(theta,1), 1]);

        logp = l_mvnormal_CUDA(theta1, M.F, M.T, ...
            Amap, M.Alinc,'A', ...
            Bmap, M.Blinc, 'B', ...
            Hmap, M.Hlinc, 'H', ...
            M.A_tri, logp, theta_ne);        
    else
        logp = l_mvnormal(theta, gpuArray(M.F), M.T, M.Amap, M.Alinc, 'A', ...
            M.Bmap, M.Blinc, 'B', M.Hmap, M.Hlinc, 'H', M.A_tri);
    end
end

if ~datawhole
    logp = logp*intensity(1);
end

end
