function [logp, states_out] = m_message(theta, intensity, states_in)
%  This function sets up the evaluation of the log-likelihood by the
%  function l_egarch or l_egarch_CUDA.
%
%  Inputs:
%  theta      Matrix of particles or parameters (C.JN x C.parameters)
%  states_in  Values of v_t1-1 and epsilon_t1-1 where 
%             t1 = find(intensity > 0, 1 , 'first')  (C.JN x C.nstates)
%  intensity  Vector of current information intensity (C.segments x 1)
%
%  Output:
%  logp       Current information about theta (C.JN x 1)
%  states_out Values of v_t2 and epsilon_t2 where 
%             t2 = find(intensity > 0, 1 , 'last')  (C.JN x C.nstates)

global C E M

if length(intensity) > C.tlast
    error('%d information segments demanded, %d available', ...
        length(intensity), C.tlast)
end

muY = u_collectpart(theta, M.muYmap, M.muYlinc, 'muY');
sigY = u_collectpart(theta, M.sigmaYmap, M.sigmaYlinc, 'sigmaY');
alph = u_collectpart(theta, M.alphamap, M.alphalinc, 'alpha');
bet = u_collectpart(theta, M.betamap, M.betalinc, 'beta');
gam = u_collectpart(theta, M.gammamap, M.gammalinc, 'gamma');
p = u_collectpart(theta, M.pmap, M.plinc, 'p');
mu = u_collectpart(theta, M.mumap, M.mulinc, 'mu');
sig = u_collectpart(theta, M.sigmamap, M.sigmalinc, 'sigma');

if E.gpu
    % Change current code to conform with handling in other models.
    logp = u_allocate([size(theta,1),1]);
    vout = u_allocate(size(states_in(:,M.vindex)));
    epsout = u_allocate(size(states_in(:,M.epsindex)));
    [logp, states_out(:, M.vindex), states_out(:, M.epsindex) ]...
     = l_egarch_CUDA(muY, sigY, alph, bet, gam, p, mu, sig,...
    M.data, intensity, states_in(:,M.vindex), states_in(:,M.epsindex), ...
    logp, vout, epsout);
   
else
   
    [logp, states_out(:,M.vindex), states_out(:,M.epsindex)] = ...
        l_egarch(muY, sigY, alph, bet, gam, p, mu, sig,...
        M.data, intensity, states_in(:,M.vindex), states_in(:,M.epsindex));
    
end

end
    
