function y = ...
    m_egarch1sim(muY, sigY, alpha, beta, gamma, p, mu, sig, t1, t2, nsim)
%  Simulate time series from periods t1 through t2 using initial values
%  of zero for v_t1-1 and epsilon_t1-1.
%
%  Inputs:
%  muY      Mean of y_t  (scalar)
%  sigY     Standard deviation of y_t  (scalar)
%  alpha    Alpha parameters of volatility dynamics (K x 1)
%  beta     Beta parmaeters of volatility dynamics (K x 1)
%  gamma    Gamma parameters of volatility dynamics (K x 1)
%  p        Parameters p_i of epsilon normal mixture (I x 1)
%  mu       Parameters mu_i of epsilon normal mixture (I x 1)
%  sig      Parameters sig_i of epsilon normal mxiture (I x 1)
%  t1       Initial period simulated
%  t2       Final period simulated
%  nsim     Number of paths simulated
%
%  Output:
%  y        Simulated paths; if t1 > 1 then y_1:t1-1 = 0   (nsim x t2)

y = zeros(nsim,t2);
shift = sqrt(2/pi);
for isim = 1:nsim
    vlag = zeros(length(alpha),1);
    epslag = 0;
    for t = t1:t2
        v = alpha.*vlag + beta*(abs(epslag) - shift) + gamma*epslag;
        j = find(mnrnd(1,p)==1);
        eps = normrnd(mu(j),sig(j));
        y(isim,t) = muY + sigY*exp(0.5*sum(v))*eps;
        vlag = v; 
        epslag = eps;
    end
end