function theta = m_partheta1(muY, sigY, alpha, beta, gamma, p, mu, sig, K, I)
%  Transform a single value of the model parameters to the algorithm 
%  parameter vector theta.  The mapping in this direction is not unique.
%  the code assumes that sum(pstar) = 1 and c = 1.
%
%  Inputs:
%  theta      Algorithm parameter vector (1 x Number of parameters)
%  K          Number of volatility components
%  I          Number of epsilon norma mixture components
%
%  Outputs:
%  muY      Mean of y_t
%  sigY     Standard deviation of y_t
%  alpha    Alpha parameters of volatility dynamics (K x 1)
%  beta     Beta parmaeters of volatility dynamics (K x 1)
%  gamma    Gamma parameters of volatility dynamics (K x 1)
%  p        Parameters p_i of epsilon normal mixture (I x 1)
%  mu       Parameters mu_i of epsilon normal mixture (I x 1)
%  sig      Parameters sig_i of epsilon normal mxiture (I x 1)

indexalpha = 3:2+K;
indexbeta = indexalpha + K;
indexgamma = indexbeta + K;
indexpstar = indexgamma(K)+1:indexgamma(K)+I;
indexmustar = indexpstar + I;
indexsigstar = indexmustar + I;
theta = zeros(1,2+3*K+I);
theta(1) = 1000*muY;
theta(2) = log(sigY);
theta(indexalpha) = atanh(alpha)';
theta(indexbeta) = log(beta)';
theta(indexgamma) = gamma';
theta(indexpstar) = atanh(p - 1);
theta(indexmustar) = mu;
theta(indexsigstar) = log(sig);

end