function [muY, sigY, alpha, beta, gamma, p, mu, sig] = ...
    m_thetapar1(theta, K, I)
%  Transform a single value of the algorithm parameter vector theta to
%  the model parameters.
%
%  Inputs:
%  theta      Algorithm parameter vector (1 x Number of parameters)
%  K          Number of volatility components
%  I          Number of epsilon norma mixture components
%
%  Outputs:
%  muY      Mean of y_t
%  sigY     Standard deviation of y_t
%  alpha    Alpha parameters of volatility dynamics (K x 1)
%  beta     Beta parmaeters of volatility dynamics (K x 1)
%  gamma    Gamma parameters of volatility dynamics (K x 1)
%  p        Parameters p_i of epsilon normal mixture (I x 1)
%  mu       Parameters mu_i of epsilon normal mixture (I x 1)
%  sig      Parameters sig_i of epsilon normal mxiture (I x 1)

indexalpha = 3:2+K;
indexbeta = indexalpha + K;
indexgamma = indexbeta + K;
indexpstar = indexgamma(K)+1:indexgamma(K)+I;
indexmustar = indexpstar + I;
indexsigstar = indexmustar + I;
muY = 0.001*theta(1);
sigY = exp(theta(2));
alpha = tanh(theta(indexalpha))';
beta = exp(theta(indexbeta))';
gamma = theta(indexgamma)';
pstar = tanh(theta(indexpstar))' + 1;
mustar = theta(indexmustar)';
sigstar = exp(theta(indexsigstar))';
p = pstar./sum(pstar);
mustarstar = mustar - dot(p,mustar);
c = 1/sqrt(dot(p,(mustarstar.^2 + sigstar.^2)));
mu = mustarstar*c;
sig = sigstar*c;

end