function [muY, sigY, alpha, beta, gamma, p, mu, sig] = ...
    m_thetapar2(theta, K, I)
%  Transform multiple values of the algorithm parameter vectors theta to
%  the model parameters.
%
%  Inputs:
%  theta      Algorithm parameter vector (n x (2+3*(K+I)))
%  K          Number of volatility components
%  I          Number of epsilon norma mixture components
%
%  Outputs:
%  muY      Mean of y_t ( n x 1)
%  sigY     Standard deviation of y_t (n x 1)
%  alpha    Alpha parameters of volatility dynamics (n x K)
%  beta     Beta parmaeters of volatility dynamics (n x K)
%  gamma    Gamma parameters of volatility dynamics (n x K)
%  p        Parameters p_i of epsilon normal mixture (n x I)
%  mu       Parameters mu_i of epsilon normal mixture (n x I)
%  sig      Parameters sig_i of epsilon normal mxiture ((n x I)


indexalpha = 3:2+K;
indexbeta = indexalpha + K;
indexgamma = indexbeta + K;
indexpstar = indexgamma(K)+1:indexgamma(K)+I;
indexmustar = indexpstar + I;
indexsigstar = indexmustar + I;
muY = 0.001*theta(:,1);
sigY = exp(theta(:,2));
alpha = tanh(theta(:,indexalpha));
beta = exp(theta(:,indexbeta));
gamma = theta(:,indexgamma);
pstar = tanh(theta(:,indexpstar)) + 1;
mustar = theta(:,indexmustar);
sigstar = exp(theta(:,indexsigstar));
p = pstar./repmat(sum(pstar,2),1,I);
mustarstar = mustar - repmat(sum(p.*mustar,2),1,I);
c = 1./repmat(sqrt(sum(p.*(mustarstar.^2 + sigstar.^2),2)),1,I);
mu = mustarstar.*c;
sig = sigstar.*c;

end