function outcompile = compile_cuda()
%COMPILE_CUDA : Negative Binomial helper script to compile CUDA code to MEX
%
% Default behaviour is to 
% <a href="matlab:pause(0)">always recompile before execution</a>.  
% To disable compilation, 
% <a href="matlab: opentoline(compile_cuda.m,22)">open the code editor</a> 
% and set: compilenow = false.
%
% Input(s): 
%
% None
% 
% Output(s): 
%
% l_negative_binomial_CUDA.mex - for evaluating log-likelihood of the 
% Negative Binomial model on GPU

global M P E
function_name = 'l_negative_binomial_CUDA';

compilenow = true; % Set to false to disable auto-recompilation
outcompile = 0;

if exist('M')
    if isfield(M,'modeldir')
        model_includepath = [M.modeldir,filesep,'cufiles'];
    else
        assumed_location=pwd;
        model_includepath = [assumed_location,filesep,'cufiles'];
    end
else
    assumed_location=pwd;
    model_includepath = [assumed_location,filesep,'cufiles'];
end

if exist('E')
    if isfield(E,'SABLrootdir')
        if ~isempty(E.SABLrootdir)
            libpath = [E.SABLrootdir,filesep,'library',filesep,'cufiles'];
        else
            assumed_location = pwd;
            libpath = [assumed_location,filesep,'cufiles'];
        end
    else
        assumed_location = pwd;
        libpath = [assumed_location,filesep,'cufiles'];
    end
else
    libpath = model_includepath;
end

srcfile = [libpath,filesep,function_name,'.cu'];

if ispc
    mxoptsfile = [model_includepath,filesep,'mex_CUDA_win64.xml'];
end
if isunix
    mxoptsfile = [model_includepath,filesep,'mex_CUDA_glnxa64.xml'];
end

if exist('P')
    if isfield(P,'projectdir')
        if ~isempty(P.projectdir)
            project_includepath = [P.projectdir,filesep,'cufiles'];
        else
            assumed_location=pwd;
            project_includepath = [assumed_location,filesep,'cufiles'];            
        end
    else
        assumed_location=pwd;
        project_includepath = [assumed_location,filesep,'cufiles'];
    end
else
    project_includepath = model_includepath;
end
if ispc
    fullstr = [' -DSABL_WIN '];
elseif isunix
    fullstr = [' -DSABL_LINUX '];
end
    
if exist(srcfile,'file')
    if compilenow == true           
        g=gpuDevice;
        if isunix
            cublaspath=[matlabroot,filesep,'bin',filesep,lower(computer),filesep,'libcublas.so.',sprintf('%1.1f',g.ToolkitVersion)];    
            defaultcublas=[];
        elseif ispc
            cublaspath=[];
            defaultcublas=' -lcublas ';
        end
        eval(['mex -silent -largeArrayDims',' -f ''', mxoptsfile,'''',' -I''',pwd,'''',' -I''',project_includepath,'''',' -I''',model_includepath,'''',' -I''',libpath,'''',' LINKLIBS=''$LINKLIBS ',cublaspath,'''',defaultcublas,fullstr,' ''', srcfile,'''']);
        outcompile = 1;
    end  
else
    outcompile = -1;
end
