function logp = m_message(theta, intensity)
%  This function sets up the evaluation of the log-likelihood by the
%  function l_negative_binomial or l_negative_binomial_CUDA.
%
%  Inputs:
%  theta      Matrix of particles (C.JNwork x C.parameters)
%  intensity  Vector of current information intensity (C.tlast x 1)
%
%  Output:
%  logp       Current information about theta


global C E M 

if M.easymap
    if E.gpu
        logp = l_negative_binomial_CUDA(theta(:, M.betmap), ...
            theta(:, M.gammap), M.data, M.x_pointer, ...
            M.z_pointer, M.y_pointer, intensity);
    else
        logp = l_negative_binomial(theta(:, M.betmap), ...
            theta(:, M.gammap), M.data, M.x_pointer, ...
            M.z_pointer, M.y_pointer, intensity);
    end
else
    [bet, ~] = u_collectpart(theta, M.betmap, M.betlinc, 'bet');
    [gam, ~] = u_collectpart(theta, M.gammap, M.gamlinc, 'gam');
    if E.gpu
        logp = l_negative_binomial_CUDA(bet, gam, M.data, M.x_pointer, ...
            M.z_pointer, M.y_pointer, intensity);
    else
        logp = l_negative_binomial(bet, gam, M.data, M.x_pointer, ...
            M.z_pointer, M.y_pointer, intensity);
    end
end

end