function logp = m_message(theta, intensity)
%  This function sets up the evaluation of the log-likelihood by the
%  function l_normal or l_normal_CUDA.
%
%  Inputs:
%  theta      Matrix of particles (C.JNwork x C.parameters)
%  intensity  Vector of current information intensity (C.tlast x 1)
%
%  Output:
%  logp       Current information about theta

global C M E

if length(intensity) > C.tlast
    error('%d information segments demanded, %d available', ...
        length(intensity), C.tlast) 
end

if M.easymap
    if E.gpu
        logp = l_normal_CUDA(theta(:, M.betmap), theta(:, M.gammap), ...
            M.data, M.x_pointer, M.z_pointer, M.y_pointer, intensity);
    else
        logp = l_normal(theta(:, M.betmap), theta(:, M.gammap), ...
            M.data, M.x_pointer, M.z_pointer, M.y_pointer, intensity);
    end
else
    [bet, ~] = u_collectpart(theta, M.betmap, M.betlinc, 'bet');
    [gam, ~] = u_collectpart(theta, M.gammap, M.gamlinc, 'gam');
    if E.gpu
        logp = l_normal_CUDA(bet, gam, M.data, M.x_pointer, M.z_pointer,...
            M.y_pointer, intensity);
    else
        logp = l_normal(bet, gam, M.data, M.x_pointer, M.z_pointer,...
            M.y_pointer, intensity);
    end
end

end
