function m_monitor(stage)
%  Execute monitoring functions specific to the normal model but not to
%  the project.
%
%  Intput:
%  stage        Current stage of the SABL algorithm

global C E M

p_monitor(stage);

if strcmp(stage, 'startrun') && ~C.simget 
    M = u_tidyfields(M);
    %  Data
    [~, k] = u_datacheck;
    if ~isfield(C, 'tfirst')
        C.tfirst = 1;
    end
    if ~isfield(C, 'tlast')
        C.tlast = size(M.data, 1);
    end
    u_pointercheck(M, 'M', k, 'y_pointer', 1);
    u_pointercheck(M, 'M', k, 'x_pointer', k-1);
    u_pointercheck(M, 'M', k, 'z_pointer', k-1);
    
    M.xmean = u_mean(M.data(:, M.x_pointer), 1, E.pus>1)';
    M.zmean = u_mean(M.data(:, M.z_pointer), 1, E.pus>1)';
    
    %  Model
    fprintf('\n SABL normal model\n')
    M.bet_count = length(M.x_pointer);
    M.gam_count = length(M.z_pointer);
    if ~isfield(C, 'parameters')
        C.parameters  = M.bet_count + M.gam_count;
    end
    
    % Parameters
    if ~isfield(M, 'betmap') && ~isfield(M, 'gammap')
        M.betmap = (1:M.bet_count )';
        M.gammap = (M.bet_count + (1:M.gam_count))';
    elseif isfield(M, 'betmap') && isfield(M, 'gammap')
    elseif isfield(M, 'betmap')
        error('M.betmap is specified but M.gammap is not')
    else
        error('M.gammap is specified but M.betmap is not')
    end
    
    M = u_blankfields(M, 'betlinc');
    [M, maptypebet] = u_mapcheck(M, 'M', 'betmap', [M.bet_count, 1], ...
        C.parameters, 'betlinc');
    M = u_blankfields(M, 'gamlinc');
    [M, maptypegam] = u_mapcheck(M, 'M', 'gammap', [M.gam_count, 1], ...
        C.parameters, 'gamlinc');
    M.easymap = ~any(maptypebet([1, 2, 4])) && ~any(maptypegam([1, 2, 4]));
    
    %  Prior
    if ~u_isfield(M, 'prior')
        M = u_priorcheck(M, 'M', 'betprior', 1:M.bet_count, 1, ...
            C.parameters, 'linear');
        M = u_priorcheck(M, 'M', 'gamprior', ...
            M.bet_count + (1:M.gam_count), 2, ...
            C.parameters, 'linear');
    end
end    

end
