function y = m_normalsim(X, tsim, varargin)
%  Simulate one outcome from the Normal model for specified covariates
%  and parameter vector
%  
%  Inputs:
%  X         Matrix of covariates  (T x k)
%  tsim      Rows of X to use in the simulation (S x 1, S <= T)
%
%  Additional inputs, variant 1:
%  x_pointer Comlumns of the data storing x variables
%  z_pointer Comlumns of the data storing z variables
%  theta     Algorithm parameters
%  betmap    Map from theta to beta
%  gammap    Map from theta to beta
%
%  Additional inputs, variant 2:
%  x_pointer Comlumns of the data storing x variables
%  z_pointer Comlumns of the data storing z variables
%  theta     Algorithm parameters
%  betmap    Map from theta to beta
%  betlinc   Linear combinations for map
%  gammap    Map from theta to beta
%  gamlinc   Linear combinations for map
%
%  Output:
%  ysim      One simulated outcome  (S x 1)

npars = [5, 7];
if ~any(npars == length(varargin))
    error('Function requires either 7 or 9 inputarguments')
end

if length(varargin) == 5
    x_pointer = varargin{1};
    z_pointer = varargin{2};
    theta     = varargin{3};
    betmap    = varargin{4};
    gammap    = varargin{5};
    
    JN = size(theta, 1);
    
    bet1 = theta(:, betmap);
    gam1 = theta(:, gammap);
    
    S = length(tsim);
    y = zeros(S, JN);
    for i = 1:S
        data1 = u_setdatatype(X(tsim(i), :), 'cpu');
        
        mu1 = bet1*data1(x_pointer)';
        std1 = sqrt(exp(gam1*data1(z_pointer)'));
        
        y(i, :) = (mu1 + std1.*randn(JN, 1))';
    end
    
elseif length(varargin) == 7
    
    x_pointer = varargin{1};
    z_pointer = varargin{2};
    theta     = varargin{3};
    betmap    = varargin{4};
    betlinc   = varargin{5}; 
    gammap    = varargin{6};
    gamlinc   = varargin{7};
    
    JN = size(theta, 1);
    
    bet1 = u_collectpart(theta, betmap, betlinc, 'bet');
    gam1 = u_collectpart(theta, gammap, gamlinc, 'gam');
    
    S = length(tsim);
    y = zeros(S, JN);
    for i = 1:S
        data1 = u_setdatatype(X(tsim(i), :), 'cpu');
        
        mu1 = bet1*data1(x_pointer)';
        std1 = sqrt(exp(gam1*data1(z_pointer)'));
        
        y(i, :) = (mu1 + std1.*randn(JN, 1))';
    end
end

end