function m_monitor(stage)
%  Execute monitoring functions specific to the Poisson model but not to 
%  the project.
%
%  Intput:
%  stage        Current stage of the SABL algorithm

global C M

p_monitor(stage);

if strcmp(stage, 'startrun') && ~C.simget
    M = u_tidyfields(M);
    
    %  Data
    [~, k] = u_datacheck;
    u_pointercheck(M, 'M', k, 'x_pointer', k-1, 'y_pointer', 1)
    M.xmean = mean(M.data(:,M.x_pointer))';
    
    %  Model
    fprintf('\n SABL Poisson model\n')
    M.betacount = length(M.x_pointer);
    if ~isfield(C, 'parameters')
        C.parameters = M.betacount;
    end
    
    % Parameters
    if ~isfield(M, 'betamap')
        M.betamap = (1:C.parameters)';
    end
    M = u_blankfields(M, 'betalinc');
    [M, maptype] = u_mapcheck(M, 'M', 'betamap', [M.betacount, 1], ...
        C.parameters, 'betalinc');
    M.easymap = ~any(maptype([1, 2, 4]));
    
    %  Prior
    if ~u_isfield(M, 'prior')
        M = u_priorcheck(M, 'M', 'betaprior', 1:C.parameters, 1, ...
            C.parameters, 'linear');
    end

end
    
end   
