function ysim = m_poissonsim(X, tsim, varargin)
%  Simulate one outcome from the Poisson model for specified covariates
%  and parameter vector
%  
%  Inputs:
%  X       Matrix of covariates  (T x k)
%  tsim    Rows of X to use in the simulation (S x 1, S <= T)
%
%  Additional inputs, variant 1:
%  theta    Algorithm parameters = Model parameters  (JN x k)
%
%  Additional inputs, variant 2:
%  theta     Algorithm parameters
%  betamap   Map from theta to beta
%  betalinc  Linear combinations for map
%  name      Code name to assist p_thetapar
%
%  Output:
%  ysim      One simulated outcome  (S x 1)

npars = [1, 4];
if ~any(npars == length(varargin))
    error('Function requires either 3 or 6 inputarguments')
end

T = length(tsim);

if length(varargin) == 1
    theta = varargin{1};  % k x 1
    ysim = poissrnd(u_setdatatype(exp(theta*X(tsim,:)'), 'cpu'));  %  JN x T
    
elseif length(varargin) == 4
    theta = varargin{1};
    betamap = varargin{2};
    betalinc = varargin{3};
    betaname = varargin{4};
    beta = squeeze(u_3dpart(theta, betamap, betalinc, betaname));
    JN = size(theta, 1);
    ysim = zeros(T, JN);
    for j = 1:JN
        ysim(:,j) = poissrnd(u_setdatatype(exp(X(tsim,:)*beta(:,j)'), 'cpu'));
    end
    
else
    error('Function has %d input arguments ~= permitted 3 or 6', ...
        2+length(varargin))
end

end 
