function p_monitor(stage)
%  Set up the information structure for this project. Default fields in the
%  M structure are for illustration only, so they will be re-set, in
%  general. Set up any additional infrastructure specific to the project,
%  creating a P structure to do so if desired.
%
%  Intput:
%  stage        Current stage of the SABL algorithm

%  The following code loads the data set for Klein model 1. The data is
%  collected from Theil (1971). The detailed data description can be found
%  therein.
%
%  In this project, the precision Matrix is assumed to follow Wishart
%  distribution.     
%
%  Note that the elements of A is the combination of elements of matrix B
%  in this project
global C Cpar E M P

if strcmp(stage, 'open')
    % E.gpu = true;
    % E.pus = 2;
    
elseif strcmp(stage, 'startrun')
%     C.Cphase_method = 'anneal_optimize';
   
    M.specification = 'FI';
    load MData
    M.data = [ones(21, 1) MData(2:22, 8) MData(2:22, 9) MData(1:21, 6) ...
        MData(1:21, 3)+MData(1:21, 9) MData(2:22, 7) MData(2:22, 5) ...
        MData(2:22, 10) MData(2:22, 1) MData(2:22, 4) MData(2:22, 3)];
    M.data = u_setdatatype(M.data, 'default');
    
    M.y_pointer = [9 10 11]';
    M.x_pointer = (1:8)';
    
    % Specify the number of variables needed to be estimated
    M.A_counter  = 0;
    M.B_counter  = 12;
    M.H_counter  = 6;
    
    % Specify the prior mean of the elements of B(theta)   
    C.Cstop.ress = 0.5;
    C.Mstop.steps = 1000;
    C.Mstop.steps_end = 3000;
    M.meanB = u_allocate([1,12]);
    M.meanB([1 5 9]) = mean(M.data(:,M.y_pointer));
    
    M.Amap = [ 2 2  -1; ...
               6 6  -2; ...
              10 10  0];
    M.Alinc = zeros(18,2);
    M.Alinc(4,1) = 1;  M.Alinc(4,2) = -1;
    M.Alinc(6,2) = -1; 
    
    M.Bmap = [1 2  -1  3 -2 4 0 0; ...
              5 6  -3  7 -4 0 8 0; ...
              9 10 11 12  0 0 0 0];
    M.Blinc = zeros(18,4);
    M.Blinc(2,1) = -1;
    M.Blinc(3,2) = -1;
    M.Blinc(6,3) = -1;
    M.Blinc(7,4) = -1;
    
    M.Hmap = [13 14 16; ...
               0 15 17; ...
               0  0 18];
%     M.Hlinc = [];
    
    M.stdB = u_allocate([1,12]);
    t2 = M.data(:,2)+M.data(:,3);
    t3 = M.data(:,4)-M.data(:,5);
    t4 = M.data(:,4);
    t6 = M.data(:,2)-M.data(:,3);
    t7 = M.data(:,4)-M.data(:,5);
    t8 = M.data(:,7);
    t10 = M.data(:,2);
    t11 = M.data(:,4);
    t12 = M.data(:,8);
    M.stdB(2:4) = std(M.data(:,7))./std([t2, t3, t4]);
    M.stdB(1) = sqrt((mean([t2,t3,t4]).^2)*(M.stdB(2:4).^2)');
    M.stdB(6:8) = std(M.data(:,8))./std([t6,t7,t8]);
    M.stdB(5) = sqrt((mean([t6,t7,t8]).^2)*(M.stdB(6:8).^2)');
    M.stdB(10:12) = std(M.data(:,9))./std([t10,t11,t12]);
    M.stdB(9) = sqrt((mean([t10,t11,t12]).^2)*(M.stdB(10:12).^2)');
    
    C.tfirst = 1;
    C.tlast = size(M.data, 1);
    C.parameters = 18;
    
    %  Part 4: Set up the prior
    M.prior{1}.distribution = 'normal';
    M.prior{1}.mean = M.meanB';
    M.prior{1}.std = M.stdB';
    M.prior{1}.columns = (1:12)';
    M.prior{1} = u_prior_linearsetup(M.prior{1});
    
    M.prior{2}.variance = eye(3);
    M.prior{2}.df = 5;
    M.prior{2}.columns = (13:18)';
    M.prior{2} = u_prior_wishartsetup(M.prior{2});
    
elseif strcmp(stage, 'finish')
    
    [Aest, M.Amap] = u_collectpart(Cpar.theta, M.Amap, M.Alinc, 'A');
    [Best, M.Bmap] = u_collectpart(Cpar.theta, M.Bmap, M.Blinc, 'B');
    
    Amean = u_allocate([M.n, M.n]);
    Astd  = u_allocate([M.n, M.n]);
    for i = 1:M.n
        for j = 1:M.n
            if M.Amap(i,j) == 0
                Amean(i,j) = 0;
                Astd(i,j) = 0;
            else
                Amean(i,j) = u_mean(Aest(:,M.Amap(i,j)), 1, E.pus>1);
                Astd(i,j) = u_std(Aest(:,M.Amap(i,j)), 1, E.pus>1);
            end
        end
    end
    disp('A posterior mean');  disp(Amean)
    disp('A posteror std');  disp(Astd)

    Bmean = u_allocate([M.n, M.k]);
    Bstd  = u_allocate([M.n, M.k]);
    for i = 1:M.n
        for j = 1:M.k
            if M.Bmap(i,j) == 0
                Bmean(i,j) = 0;
                Bstd(i,j) = 0;
            else
                Bmean(i,j) = u_mean(Best(:,M.Bmap(i,j)), 1, E.pus>1);
                Bstd(i,j) = u_std(Best(:,M.Bmap(i,j)), 1, E.pus>1);
            end
        end
    end
    disp('B posterior mean');  disp(Bmean)
    disp('B posteror std');  disp(Bstd)
    
    Hmean = u_allocate([M.n, M.n]);
    Hstd  = u_allocate([M.n, M.n]);
    for i = 1:M.n
        for j = i:M.n
            xx = Cpar.theta(:, M.Hmap(i,j));
            if i == j
                xx = exp(xx);
            end
            Hmean(i,j) = u_mean(xx, 1, E.pus>1);
            Hstd(i,j) = u_std(xx, 1, E.pus>1);
        end
    end
    
    disp('H posterior mean');  disp(Hmean)
    disp('H posteror std');  disp(Hstd)

end
    
end