function A = p_thetapar(theta, name, ii, jj, columns, A_in)
%  Handle parameters of the egarch model requiring nonlinear
%  transformations of theta.
%
%  Inputs:
%  theta      Matrix of algorithm particles (C.JNwork x C.parameters)
%  name       Name of parameter
%  ii         Target row of 
%  Transform multiple values of the algorithm parameter vectors theta to
%  the model parameters.
%
%  Inputs:
%  theta      Algorithm parameter vector (n x (2+3*(K+I)))
%  K          Number of volatility components
%  I          Number of epsilon norma mixture components
%
%  Outputs:
%  muY      Mean of y_t ( n x 1)
%  sigY     Standard deviation of y_t (n x 1)
%  alpha    Alpha parameters of volatility dynamics (n x K)
%  beta     Beta parmaeters of volatility dynamics (n x K)
%  gamma    Gamma parameters of volatility dynamics (n x K)
%  p        Parameters p_i of epsilon normal mixture (n x I)
%  mu       Parameters mu_i of epsilon normal mixture (n x I)
%  sig      Parameters sig_i of epsilon normal mxiture ((n x I)

global C M Ppar

if strcmp(name, 'sigmaY')
    A = exp(theta(:,M.sigmaYmap-C.parameters));
elseif strcmp(name, 'alpha')
    A = tanh(theta(:,M.alphamap-C.parameters));
elseif strcmp(name, 'beta')
    A = exp(theta(:,M.betamap-C.parameters));
elseif strcmp(name, 'p')
    pstar = tanh(theta(:,M.pmap-C.parameters)) + 1;
    Ppar.p = pstar./repmat(sum(pstar,2), 1, M.I);
    A = Ppar.p;
elseif strcmp(name, 'mu')
    mustar = theta(:,M.mumap-C.parameters);
    mustarstar = mustar - repmat(sum(Ppar.p.*mustar,2), 1, M.I);
    Ppar.sigstar = exp(theta(:,M.sigmamap-C.parameters));
    Ppar.c = 1./repmat(sqrt(sum(Ppar.p.*(mustarstar.^2 + Ppar.sigstar.^2),2)),...
        1, M.I);
    A = mustarstar.*Ppar.c;
elseif strcmp(name, 'sigma')
    A = Ppar.sigstar.*Ppar.c;
else
    A = A_in;
end

end