function p_monitor(stage)
%  Set up the information structure for this project.
%  Default fields in the M structure are for illustration only, so
%  they will be re-set, in general.
%  Set up any additional infrastructure specific to the project,
%  creating a P structure to do so if desired.
global C Cpar E M P
persistent step

if P.test  %  --------------------------------------------------------
    if strcmp(stage, 'open')
        E.gpu = (P.gpu == 2);
        E.pus = P.workers;
        
        step = P.step;
        if step == 2
            E.simulation_get = 'simfile';
        end
        
    elseif strcmp(stage, 'startrun')
        
        C.Cphase_method = char(P.Cphase_method{P.Cphase});
        C.Mphase_method = char(P.Mphase_method(P.Mphase));
        C.twopass = (P.twopass == 2);
        C.J = 16;
        C.N = 1024;
        C.detail_level = 7;
        T = 1024;
        load garch_data;
        dy = diff(log(g_data));
        M.data = dy(1:T);
        M.data = u_setdatatype(M.data);
        if step <= 1
            M.data = M.data(1:50, :);
        else
            M.data = M.data(1:100, :);
        end
        M.y_pointer = 1;
        M.K = 2;
        M.I = 3;
        
        C.tlast = size(M.data, 1);
        
        M.muYprior.mean = 0;
        M.muYprior.std = 1;
        M.sigmaYprior.mean = log(0.01);
        M.sigmaYprior.std = 1;
        M.alphaprior.mean = atanh(0.95);
        M.alphaprior.std = 1;
        M.betaprior.mean = log(0.1);
        M.betaprior.std = 1;
        M.gammaprior.mean = 0;
        M.gammaprior.std = 0.2;
        M.muprior.mean = 0;
        M.muprior.std = 0.2;
        M.pprior.mean = 0;
        M.pprior.std = 0.2;
        M.sigmaprior.mean = 0;
        M.sigmaprior.std = 0.2;
        C.detail_level = 7;
        C.nlcuda = false;
        
    elseif strcmp(stage, 'finish')
        
        P.tmean = u_mean(Cpar.theta, 1, E.pus>1);
        P.tstd = u_std(Cpar.theta, 1, E.pus>1);
        P.tnse = u_nse(Cpar.theta, C.N, E.pus>1);
        P.trne = u_rne(Cpar.theta, C.N, E.pus>1);
        
        if ~strcmp(C.Cphase_method, 'anneal_optimize')
            P.logml1 = C.logml1;
            P.logmlnse = C.logmlnse;                    
        else                                             
            P.logml1 = 0;                                
        end
        
    elseif strcmp(stage, 'close')
        if step == 1
            E.simulation_record = 'simfile';
        end
    end
    
else  %  -----------------------------------------------------------------
    
end

end



