function p_monitor(stage)
%  Set up the information structure for this project. Default fields in the
%  M structure are for illustration only, so they will be re-set, in
%  general. Set up any additional infrastructure specific to the project,
%  creating a P structure to do so if desired.
%
%  Intput:
%  stage        Current stage of the SABL algorithm

global C Cpar E M P
    
if strcmp(stage, 'open')
    % E.gpu = true;
    % E.pus = 2;
    
elseif strcmp(stage, 'startrun')
    % Change SABL default parameters as desired.
    load datfile
    M.data = data;
    M.x_pointer = [1 2];
    M.z_pointer = [1 3];
    M.y_pointer = 4;
    C.tfirst = 1;
    C.tlast = size(M.data, 1);
    
    if P.example == 1
        M.betprior.distribution = 'normal';
        M.betprior.mean = [1; 0];
        M.betprior.std = ones(2,1);
        M.betprior = u_prior_linearsetup(M.betprior);
        
        M.gamprior.distribution = 'normal';
        M.gamprior.mean = [1; 0];
        M.gamprior.std = ones(2,1);
        M.gamprior = u_prior_linearsetup(M.gamprior);
        
    elseif P.example == 2
        M.betprior.distribution = 'Student-t';
        M.betprior.df = 6;
        M.betprior.mean = [1; 0];
        M.betprior.variance = eye(2);
        M.betprior = u_prior_linearsetup(M.betprior);
        
        M.gamprior.distribution = 'Student-t';
        M.gamprior.df = 6;
        M.gamprior.mean = [1; 0];
        M.gamprior.variance = eye(2);
        M.gamprior = u_prior_linearsetup(M.gamprior);
        
    elseif P.example == 3
        %         M.betmap = [1 2];
        M.betprior.distribution = 'normal';
        M.betprior.mean = [1; 0];
        M.betprior.std = ones(2, 1);
        M.betprior.constraints.a = [0; 0.48];
        M.betprior.constraints.b = inf(2, 1);
        M.betprior.constraints.D = [zeros(2,1), eye(2)];
        M.betprior = u_prior_linearsetup(M.betprior);
        
        M.gamprior.distribution = 'normal';
        M.gamprior.mean = [1; 0];
        M.gamprior.std = ones(2, 1);
        M.gamprior.constraints.a = [0; 0.48];
        M.gamprior.constraints.b = inf(2, 1);
        M.gamprior.constraints.D = [zeros(2,1), eye(2)];
        M.gamprior = u_prior_linearsetup(M.gamprior);
    end
    
elseif strcmp(stage, 'endrun')
    
    if C.passone
        P.parstats1 = [mean(Cpar.theta)', std(Cpar.theta)', ...
            u_nse(Cpar.theta, C.N, E.pus>1)', u_rne(Cpar.theta,C.N, E.pus>1)'];
        disp(P.parstats1)
        P.mlstats1 = [C.logml1, C.logml2, C.logmlnse]';
        fig = 1;
    else
        P.parstats2 = [mean(Cpar.theta)', std(Cpar.theta)', ...
            u_nse(Cpar.theta, C.N, E.pus>1)', u_rne(Cpar.theta,C.N, E.pus>1)'];
        disp(P.parstats2)
        P.mlstats2 = [C.logml1, C.logml2, C.logmlnse]';
        fig = 2;
        disp('t-test comparisons of parameters in pass one and pass two')
        tstat = (P.parstats1(:,1) - P.parstats2(:,1))./...
            sqrt(P.parstats1(:,3).^2 + P.parstats2(:,3).^2);
        disp(tstat)
        disp('t-test comparison of ML stats in pass one and pass two')
        tse = sqrt(P.mlstats1(3).^2 + P.mlstats2(3).^2);
        tstat = (P.mlstats1(1:2)- P.mlstats2(1:2))/tse;
        disp(tstat')
    end
    figure(fig)
    for i = 1:size(Cpar.theta, 2)
        subplot(2,2,i)
        hist(Cpar.theta(:,i), 20)
    end
    
elseif strcmp(stage, 'finish')
    bet = u_collectpart(Cpar.theta, M.betmap, M.betlinc, 'bet');
    gam = u_collectpart(Cpar.theta, M.gammap, M.gamlinc, 'gam');
    bx = bet*M.xmean;
    gz = gam*M.zmean;
    fprintf('ybar = %9.5f, Std ybar = %9.5f\n',...
        u_mean(M.data(:,M.y_pointer), 1, E.pus>1), ...
        u_std(M.data(:,M.y_pointer), 1, E.pus>1)/sqrt(C.tupdate))
    fprintf('Mean of r(1-p)/p = %9.5f, Std of r(1-p)/p = %9.5f\n',...
        u_mean(exp(bx-2*gz), 1, E.pus>1), u_std(exp(bx-2*gz), 1, E.pus>1))
    fprintf('Mean of over-dispersion = %9.5f, Std of over-dispersion = %9.5f\n',...
        u_mean(1./exp(gz), 1, E.pus>1), u_std(1./exp(gz), 1, E.pus>1))

elseif strcmp(stage, 'close')
    
    Cpar.theta1 = u_mixmap(Cpar.theta);    
    
end
