function A = p_thetapar(theta, name, ii, jj, columns, A_in)
%  Execute the nonlinear transformation from 
%      theta(1:3) = [log(alpha_s), log(aplpha_c), log(p)]
%  to beta(2:4).
%
%  Inputs:
%  theta     Matrix of particles (C.JNwork x C.parameters)
%  name      'bet' for beta, 'gam' for gamma
%  ii        Entries are [2, 3, 4] corresponding to beta parameter map
%  jj        Entires are [1, 1, 1] (Redundant because size(betmap, 2) = 1)
%  columns   Indexes columns of A corresponding to 
%  A_in      Parameter particle matrix on input, linear entries filled
%
%  Output:
%  A         Parameter particle matrix with nonlinear entries filled
%            and hence entire A is now filled

if strcmp(name, 'gam')
    return  % Place-holder for nonlinear gamma elements, if added sometime
end

A = A_in;
alpha_s = exp(theta(:,ii(1)));
alpha_c = exp(theta(:,ii(2)));
p = exp(theta(:,ii(3)));
ac_costerm = alpha_c.*cos(2*pi./p)*2;

A(:,columns(1)) = alpha_s + ac_costerm;  % beta(2)
A(:,columns(2)) = -(alpha_s.*ac_costerm + alpha_c.^2);  % beta(3)
A(:,columns(3)) = alpha_s.*alpha_c.^2;  % beta(4)

end