function p_monitor(stage)
%  Set up the information structure for this project. Default fields in the
%  M structure are for illustration only, so they will be re-set, in
%  general. Set up any additional infrastructure specific to the project,
%  creating a P structure to do so if desired.
%
%  Intput:
%  stage        Current stage of the SABL algorithm

global C Cpar E M P
    
if strcmp(stage, 'open')
    % E.gpu = true;
    % E.pus = 2;
    
elseif strcmp(stage, 'startrun')
    %  Part 1: Set up the data
    %  Part 2: Change SABL default parametera
    %  Part 3: Map algorithm parameters (theta) to model parameters (zeta)
    %  Part 4: Set up the prior
    
    load datfile;
    M.data = data;
    C.tfirst = 1;
    C.tlast = size(M.data, 1);
    M.x_pointer = [1, 2]';
    M.z_pointer = [1, 3]';
    M.y_pointer = 4;
    
    if P.example == 1
        M.betprior.distribution = 'normal';
        M.betprior.mean = [1; 0];
        M.betprior.std = ones(2,1);
        M.betprior = u_prior_linearsetup(M.betprior);
        
        M.gamprior.distribution = 'normal';
        M.gamprior.mean = [1; 0];
        M.gamprior.std = ones(2,1);
        M.gamprior = u_prior_linearsetup(M.gamprior);
        
    elseif P.example == 2
        M.betprior.distribution = 'Student-t';
        M.betprior.df = 6;
        M.betprior.mean = [1; 0];
        M.betprior.variance = eye(2);
        M.betprior = u_prior_linearsetup(M.betprior);
        
        M.gammap = [1 2];
        M.gamprior.distribution = 'Student-t';
        M.gamprior.df = 6;
        M.gamprior.mean = [1; 0];
        M.gamprior.variance = eye(2);
        M.gamprior = u_prior_linearsetup(M.gamprior);
        
    elseif P.example == 3
        M.betprior.distribution = 'normal';
        M.betprior.mean = [1; 0];
        M.betprior.std = ones(2, 1);
        M.betprior.constraints.a = [0; 0.48];
        M.betprior.constraints.b = inf(2, 1);
        M.betprior.constraints.D = eye(2);
        M.betprior = u_prior_linearsetup(M.betprior);
        
        M.gamprior.distribution = 'normal';
        M.gamprior.mean = [1; 0];
        M.gamprior.std = ones(2, 1);
        M.gamprior.constraints.a = [0; 0.48];
        M.gamprior.constraints.b = inf(2, 1);
        M.gamprior.constraints.D = eye(2);
        M.gamprior = u_prior_linearsetup(M.gamprior);
    end
    
elseif strcmp(stage, 'endrun')
    Cpar.theta1 = u_mixmap(Cpar.theta);
    disp('Mean, standard deviation, NSE and RNE of theta')
    if C.passone
        P.parstats1 = [mean(Cpar.theta1)', std(Cpar.theta1)', ...
            u_nse(Cpar.theta, C.N, E.pus>1)', u_rne(Cpar.theta,C.N, E.pus>1)'];
        disp(P.parstats1)
        P.mlstats1 = [C.logml1, C.logml2, C.logmlnse]';
    else
        P.parstats2 = [mean(Cpar.theta1)', std(Cpar.theta1)', ...
            u_nse(Cpar.theta, C.N, E.pus>1)', u_rne(Cpar.theta,C.N, E.pus>1)'];
        disp(P.parstats2)
        P.mlstats2 = [C.logml1, C.logml2, C.logmlnse]';
        fig = 2;
        disp('t-test comparisons of parameters in pass one and pass two')
        tstat = (P.parstats1(:,1) - P.parstats2(:,1))./...
            sqrt(P.parstats1(:,3).^2 + P.parstats2(:,3).^2);
        disp(tstat)
        disp('t-test comparison of ML stats in pass one and pass two')
        tse = sqrt(P.mlstats1(3).^2 + P.mlstats2(3).^2);
        tstat = (P.mlstats1(1:2)- P.mlstats2(1:2))/tse;
        disp(tstat')
    end
elseif strcmp(stage, 'finish')
    
elseif strcmp(stage, 'close')
    Cpar.theta1 = u_mixmap(Cpar.theta);
end

end






