function p_monitor(stage)
%  Set up the information structure for this project.
%  Default fields in the M structure are for illustration only, so
%  they will be re-set, in general.
%  Set up any additional infrastructure specific to the project,
%  creating a P structure to do so if desired.
global C Cpar E M P
persistent step

if P.test  %  --------------------------------------------------------
    if strcmp(stage, 'open')
        E.gpu = (P.gpu == 2);
        E.pus = P.workers;
        
        step = P.step;
        if step == 2
            E.simulation_get = 'simfile';
        end
        
    elseif strcmp(stage, 'startrun')
        
        C.Cphase_method = char(P.Cphase_method{P.Cphase});
        C.Mphase_method = char(P.Mphase_method(P.Mphase));
        C.twopass = (P.twopass == 2);
        C.J = 16;
        C.N = 1024;
        C.detail_level = 7;
        load Mdata
        M.data = u_setdatatype(Mdata);
        if step <= 1
            M.data = M.data(1:100, :);
        else
            M.data = M.data(1:200, :);
        end
        
        M.betmap = [1 2];
        M.betprior.distribution = 'normal';
        M.betprior.mean = [1; 0];
        M.betprior.std = ones(2,1);
        M.betprior = u_prior_linearsetup(M.betprior);
        M.betlinc = [];
        
        M.gammap = [3 4]; 
        M.gamprior.distribution = 'normal';
        M.gamprior.mean = [1; 0];
        M.gamprior.std = ones(2,1);
        M.gamprior = u_prior_linearsetup(M.gamprior);
        M.gamlinc = [];
        
        C.tlast = size(M.data, 1);
        
        M.x_pointer = [1, 2];
        M.z_pointer = [1, 3];
        M.y_pointer = 4;

    elseif strcmp(stage, 'finish')

        P.tmean = u_mean(Cpar.theta, 1, E.pus>1);
        P.tstd = u_std(Cpar.theta, 1, E.pus>1);
        P.tnse = u_nse(Cpar.theta, C.N, E.pus>1);
        P.trne = u_rne(Cpar.theta, C.N, E.pus>1);
        
        if ~strcmp(C.Cphase_method, 'anneal_optimize')
            P.logml1 = C.logml1;
            P.logmlnse = C.logmlnse;                    
        else                                             
            P.logml1 = 0;                                
        end
        
    elseif strcmp(stage, 'close')
        if step == 1
            E.simulation_record = 'simfile';
        end
    end
    
else  %  -----------------------------------------------------------------
    
end

end



