function p_monitor(stage)
%  Set up the information structure for this project. Default fields in the
%  M structure are for illustration only, so they will be re-set, in
%  general. Set up any additional infrastructure specific to the project,
%  creating a P structure to do so if desired.
%
%  Intput:
%  stage        Current stage of the SABL algorithm

global C Cpar E M P

if strcmp(stage, 'open')
    % E.gpu = true;
    % E.pus = 2;
    
elseif strcmp(stage, 'startrun')
    
    %  Part 1: Set up the data
    load Mdata
    M.data = u_setdatatype(Mdata);
    M.data = M.data(1:100, :);
    M.x_pointer = [1; 2];
    M.y_pointer = 3;
    C.tlast = size(M.data, 1);
    P.prior_predictive = false;
    M.betamap = [1; 2];
    M.betaprior.distribution = 'normal';
    M.betaprior.mean = [1; 0];
    M.betaprior.std = ones(2, 1);
    M.betaprior = u_prior_linearsetup(M.betaprior);
    C.Cphase_method = 'data_whole';
    C.Mphase_method = 'MGRW_blocked';
    % C.twopass = true;
    C.detail_level = 7;
    C.J = 16;
    C.N = 1024;
    C.Mstop.steps = 100;
    
    
elseif strcmp(stage, 'initialize')
    if P.prior_predictive
        nsim = 100;
        ysim = m_poissonsim(M.data(:,M.x_pointer), C.tfirst:C.tlast, ...
            Cpar.theta(randperm(C.JNwork, nsim), :));
        my = mean(ysim, 2);
        od = var(ysim, [], 2)./my;
        plot(log(my), log(od), 'r.'); hold on;
        datmy = mean(M.data(:,M.y_pointer));
        datod = var(M.data(:,M.y_pointer))/datmy;
        xrange = xlim;
        yrange = ylim;
        plot([log(datmy), log(datmy)], yrange, 'k:')
        plot(xrange, [log(datod), log(datod)], 'k:')
        xlabel('log Mean')
        ylabel('log Over-dispersion')
        title('Prior predictive distribution')
        pause
    end
    
elseif strcmp(stage, 'finish')
    P.tmean = u_mean(exp(Cpar.theta(:, M.betamap)*M.xmean), 1, E.pus>1);
    P.tstd  = u_std(exp(Cpar.theta(:, M.betamap)*M.xmean), 1, E.pus>1);
    P.tnse  = u_nse(exp(Cpar.theta(:, M.betamap)*M.xmean), C.N, E.pus>1);
    P.trne  = u_rne(exp(Cpar.theta(:, M.betamap)*M.xmean), C.N, E.pus>1);
    if ~strcmp(C.Cphase_method, 'anneal_optimize')
        P.logml1 = C.logml1;
        P.logmlnse = C.logmlnse;
    else
        P.logml1 = 0;
    end
    fprintf('ybar = %9.5f, Std ybar = %9.5f\n',...
        u_mean(M.data(:,M.y_pointer), 1, E.pus>1), ...
        u_std(M.data(:,M.y_pointer), 1, E.pus>1)/sqrt(C.tupdate))
    fprintf('Mean of beta*xbar = %9.5f, Std of beta*xbar= %9.5f\n',...
        P.tmean, P.tstd)
    
elseif strcmp(stage, 'endrun')
    Cpar.theta1 = u_mixmap(Cpar.theta);
    disp('Mean, standard deviation, NSE and RNE of theta')
    if C.passone
        P.parstats1 = [mean(Cpar.theta1)', std(Cpar.theta1)', ...
            u_nse(Cpar.theta, C.N, E.pus>1)', u_rne(Cpar.theta,C.N, E.pus>1)'];
        disp(P.parstats1)
        P.mlstats1 = [C.logml1, C.logml2, C.logmlnse]';
        fig = 1;
    else
        P.parstats2 = [mean(Cpar.theta1)', std(Cpar.theta1)', ...
            u_nse(Cpar.theta, C.N, E.pus>1)', u_rne(Cpar.theta,C.N, E.pus>1)'];
        disp(P.parstats2)
        P.mlstats2 = [C.logml1, C.logml2, C.logmlnse]';
        fig = 2;
        disp('t-test comparisons of parameters in pass one and pass two')
        tstat = (P.parstats1(:,1) - P.parstats2(:,1))./...
            sqrt(P.parstats1(:,3).^2 + P.parstats2(:,3).^2);
        disp(tstat)
        disp('t-test comparison of ML stats in pass one and pass two')
        tse = sqrt(P.mlstats1(3).^2 + P.mlstats2(3).^2);
        tstat = (P.mlstats1(1:2)- P.mlstats2(1:2))/tse;
        disp(tstat')
    end
    figure(fig)
    for i = 1:size(Cpar.theta1, 2)
        subplot(2,2,i)
        hist(Cpar.theta1(:,i), 20)
    end
end

end
%  Part 1: Set up the data
%  Part 2: Change SABL default parametera
 %  Part 3: Map algorithm parameters (theta) to model parameters (zeta)
 %  Part 4: Set up the prior
