function p_monitor(stage)
%  Set up the information structure for this project.
%  Default fields in the M structure are for illustration only, so
%  they will be re-set, in general.
%  Set up any additional infrastructure specific to the project,
%  creating a P structure to do so if desired.
global C Cpar E M P
persistent step 

if P.test  %  --------------------------------------------------------
    if strcmp(stage, 'open')
        E.gpu = (P.gpu == 2);
        E.pus = P.workers;
        
        step = P.step;
        if step == 2
            E.simulation_get = 'simfile';
        end
        
    elseif strcmp(stage, 'startrun')
        if E.pus > 1
            spmd
                rng('shuffle');
            end
        else
            rng('shuffle');
        end
        load Mdata
        M.data = u_setdatatype(Mdata);
        
        if step <= 1
            M.data = M.data(1:100, :);
        else
            M.data = M.data(1:200, :);
        end

        M.x_pointer = [1; 2];
        M.y_pointer = 3;
        
        C.tlast = size(M.data, 1);
        
        M.betamap = [1; 2];
        M.betaprior.distribution = 'normal';
        M.betaprior.mean = [1; 0];
        M.betaprior.std = ones(2, 1);
        M.betaprior = u_prior_linearsetup(M.betaprior);
        
        C.Cphase_method = char(P.Cphase_method{P.Cphase});
        C.Mphase_method = char(P.Mphase_method(P.Mphase));
        C.twopass = (P.twopass == 2);
        C.detail_level = 7;
        C.J = 16;
        C.N = 1024;
        C.Mstop.steps = 100;
        
    elseif strcmp(stage, 'finish')
        
        P.tmean = u_mean(exp(Cpar.theta(:, M.betamap)*M.xmean), 1, E.pus>1);
        P.tstd  = u_std(exp(Cpar.theta(:, M.betamap)*M.xmean), 1, E.pus>1);
        P.tnse  = u_nse(exp(Cpar.theta(:, M.betamap)*M.xmean), C.N, E.pus>1);
        P.trne  = u_rne(exp(Cpar.theta(:, M.betamap)*M.xmean), C.N, E.pus>1);
        if ~strcmp(C.Cphase_method, 'anneal_optimize')
            P.logml1 = C.logml1;
            P.logmlnse = C.logmlnse;
        else
            P.logml1 = 0;
        end
        fprintf('ybar = %11.7f, Std ybar = %11.7f\n',...
            u_mean(M.data(:,M.y_pointer), 1, E.pus>1), ...
            u_std(M.data(:,M.y_pointer), 1, E.pus>1)/sqrt(C.tupdate))
        fprintf('Mean of beta*xbar = %11.7f, Std of beta*xbar= %11.7f\n',...
            P.tmean, P.tstd)
        
    elseif strcmp(stage, 'close')
        if step == 1
            E.simulation_record = 'simfile';
        end
    end
else  %  -----------------------------------------------------------------
    
end

end



