function test_setspecdir
% Test u_setspecdir.m

[r1,r2] = u_setspecdir;
if ~isempty(r1) || ~isempty(r2)
    error('Wrong!');
end

[r1,r2] = u_setspecdir;
if ~isempty(r1) || ~isempty(r2)
    error('Wrong!');
end

pool = cell(2,1);
pool{1} = '';
pool{2} = ' ';
for iroot = 1:length(pool)
    root = pool{iroot};
    [r1,r2] = u_setspecdir;
    if ~isempty(r1) || ~isempty(r2)
        error('Wrong!, root = ''%s'' ', root);
    end
end

for iroot = 1:length(pool)
    root = pool{iroot};
    for imodel = 1:length(pool)
        model = pool{imodel};
        [r1, r2] = u_setspecdir(root, model);
        if ~isempty(r1) || ~isempty(r2)
            error('Wrong! root = ''%s'', model = ''%s'' ', root, model);
        end
    end
end

pool = cell(2,1);
pool{1} = '/'; % Theoretically '/' can be a valid model dircetory, but this is
% impractical. -HX, 5 Sep, 2014.
pool{2} = '//';
for iroot = 1:length(pool)
    [r1, r2] = u_setspecdir(root);
    if ~isempty(r1) || ~isempty(r2)
        error('Wrong! root = ''%s'' ', root);
    end
end

pool = cell(3,1);
pool{1} = '.';
pool{2} = './';
pool{3} = './.';
for iroot = 1:length(pool)
    root = pool{iroot};
    [r1, r2] = u_setspecdir(root);
    
    a = pwd;
    [b,c,d]=fileparts(a);
    if 1~=strcmp(r1,a) || 1~=strcmp(r2,c)
        error('Wrong! root = ''%s'' ', root);
    end
    clear a b c d
end

pool = cell(3,1);
pool{1} = '..';
pool{2} = '../';
pool{3} = '../.';
for iroot = 1:length(pool)
    a = pwd;
    cd '/';
    root = pool{iroot};
    [r1, r2] = u_setspecdir(root);
    
    if 1~=strcmp(r1,'/') || ~isempty(r2)
        error('Wrong! root = ''%s'' ', root);
    end

    cd '/Users';
    root = pool{iroot};
    [r1, r2] = u_setspecdir(root);
    
    if 1~=strcmp(r1,'/') || ~isempty(r2)
        error('Wrong! root = ''%s'' ', root);
    end

    cd '/Users/huaxinxu/Documents/MATLAB';
    root = pool{iroot};
    [r1, r2] = u_setspecdir(root);
    
    b = '/Users/huaxinxu/Documents';
    [~,c,~]=fileparts(b);
    if 1~=strcmp(r1,b) || 1~=strcmp(r2,c)
        error('Wrong! root = ''%s'' ', root);
    end

    cd(a);
    clear a b c d
end

root = 'nonexistentmodel';
[r1, r2] = u_setspecdir(root);

if ~isempty(r1) || ~isempty(r2)
    error('Wrong! root = ''%s'' ', root);
end

root = 'normal';
if 7==exist('/Users/huaxinxu/Downloads/SABL_2014a/updates_Simon', 'dir')
    movefile('/Users/huaxinxu/Downloads/SABL_2014a/updates_Simon', ...
        '/Users/huaxinxu/Downloads/');
end
if 7==exist('/Users/huaxinxu/Downloads/SABL_2014a/updates_Bin', 'dir')
    movefile('/Users/huaxinxu/Downloads/SABL_2014a/updates_Bin', ...
        '/Users/huaxinxu/Downloads/');
end
if 7==exist('/Users/huaxinxu/Downloads/SABL_2014a/updates_Huaxin', 'dir')
    movefile('/Users/huaxinxu/Downloads/SABL_2014a/updates_Huaxin', ...
        '/Users/huaxinxu/Downloads/');
end
if 7==exist('/Users/huaxinxu/Downloads/SABL_2014a/updates_John', 'dir')
    movefile('/Users/huaxinxu/Downloads/SABL_2014a/updates_John', ...
        '/Users/huaxinxu/Downloads/');
end

a = pwd;
for i = 1:3
    switch i
        case 1
            cd '/Users/huaxinxu/Documents/MATLAB';
        case 2
            cd '/Users/huaxinxu/Downloads/SABL_2014a/models';
        case 3
            cd '/Users/huaxinxu/Downloads/SABL_2014a';
    end
    [r1, r2] = u_setspecdir(root);
    if iscell(r1)
        error('Wrong! root = ''%s'', there is only one model, found multiple.', root);
    end
    if isempty(regexp(r1,'/Users/huaxinxu/Downloads/SABL_2014a', 'once')) ...
        error('Wrong! root = ''%s'', didn''t find model.', root);
    end
    if 1~=strcmp(r2,'normal')
        error('Wrong! root = ''%s'', found wrong model.', root);
    end
end
cd(a);

if 7==exist('/Users/huaxinxu/Downloads/updates_Simon','dir')
    movefile('/Users/huaxinxu/Downloads/updates_Simon', ...
        '/Users/huaxinxu/Downloads/SABL_2014a/');
end
if 7==exist('/Users/huaxinxu/Downloads/updates_Bin','dir')
    movefile('/Users/huaxinxu/Downloads/updates_Bin', ...
        '/Users/huaxinxu/Downloads/SABL_2014a/');
end
if 7==exist('/Users/huaxinxu/Downloads/updates_Huaxin','dir')
    movefile('/Users/huaxinxu/Downloads/updates_Huaxin', ...
        '/Users/huaxinxu/Downloads/SABL_2014a/');
end
if 7==exist('/Users/huaxinxu/Downloads/updates_John','dir')
    movefile('/Users/huaxinxu/Downloads/updates_John', ...
        '/Users/huaxinxu/Downloads/SABL_2014a/');
end

a = pwd;
for i = 1:3
    switch i
        case 1
            cd '/Users/huaxinxu/Documents/MATLAB';
        case 2
            cd '/Users/huaxinxu/Downloads/SABL_2014a/models';
        case 3
            cd '/Users/huaxinxu/Downloads/SABL_2014a';
    end
    [r1, r2] = u_setspecdir(root);
    if ~iscell(r1)
        error('Wrong! root = ''%s'', modeldir should be cell array ', root);
    else
        if 1>=length(r1)
            error('Wrong! root = ''%s'', %s', root, ...
                'modeldir should be cell array with length > 1');
        else
            for i = 1:length(r1)
                if isempty(regexp(r1{i},root))
                    error('Wrong! root = ''%s'', %s%s', root, ...
                        'modeldir should be a cell array with each ', ...
                        'element containing it');
                end
            end
            if 1~=strcmp(r2,root)
                error('Wrong! root = ''%s'', this should be the modelname.', root);
            end
        end
    end
end
cd(a);

pool = cell(2,1);
pool{1} = '/Users/huaxinxu/Documents/MATLAB';
pool{2} = '/Users/huaxinxu/Documents/MATLAB/';
for iroot = 1:length(pool)
    root = pool{iroot};
    [r1, r2] = u_setspecdir(root);
    [~,c,~]=fileparts('/Users/huaxinxu/Documents/MATLAB');
    
    if 1~=strcmp(r1,pool{1}) || 1~=strcmp(r2,c)
        error('Wrong! root = ''%s'' ', root);
    end
    clear c
end

a = pwd;
cd '/Users/huaxinxu/Downloads/';
pool = cell(2,1);
pool{1} = './MATLAB';
pool{2} = './MATLAB/';
for iroot = 1:length(pool)
    root = pool{iroot};
    [r1, r2] = u_setspecdir(root);
    
    if ~isempty(r1) || ~isempty(r2)
        error('Wrong! root = ''%s'' ', root);
    end
end
cd(a);

clear pool;

a = pwd;
cd '/Users/huaxinxu'

modelpool = cell(6,1);
modelpool{1} = 'nonexist';
modelpool{2} = 'MATLAB';
modelpool{3} = './nonexist';
modelpool{4} = './MATLAB';
modelpool{5} = '/Users/huaxinxu/Downloads';
modelpool{6} = 'normal';


rootpool = cell(2,1);
rootpool{1} = 'nonexist';
rootpool{2} = './nonexist';

for iroot = 1:length(rootpool)
    root = rootpool{iroot};
    for imodel = 1:length(modelpool)
        model = modelpool{imodel};
        [r1,r2] = u_setspecdir(root,model);
        if ~isempty(r1) || ~isempty(r2)
            error('Wrong! root = ''%s'' ', root);
        end
    end
end

rootpool = cell(3,1);
rootpool{1} = 'Downloads';
rootpool{2} = './Downloads';
rootpool{3} = '/Users/huaxinxu/Downloads';
for iroot = 1:length(rootpool)
    root = rootpool{iroot};
    for imodel = 1:length(modelpool)
        model = modelpool{imodel};
        [r1,r2] = u_setspecdir(root,model);
        if 1==strcmp(model,'nonexist') ...
            || 1==strcmp(model,'./nonexist') ...
            || 1==strcmp(model, '/Users/huaxinxu/Downloads') ...
            || 1==strcmp(model, 'MATLAB') ...
            || 1==strcmp(model, './MATLAB') ...
            || 1==strcmp(model, '/Users/huaxinxu/Documents/MATLAB')
            if ~isempty(r1) || ~isempty(r2)
                error('Wrong! root = ''%s'', model = ''%s'' ', root, model);
            end
        end
        
        if 1==strcmp(model,'normal')        
            if isempty(r1) || 1~=strcmp(r2,'normal')
                error('Wrong! root = ''%s'', model = ''%s'' ', root, model);
            end
            if ischar(r1) && isempty(regexp(r1,'normal','once'))
                error('Wrong! root = ''%s'', model = ''%s'' ', root, model);
            end
            if iscell(r1) && isempty(regexp(r1{1},'normal','once'))
                error('Wrong! root = ''%s'', model = ''%s'' ', root, model);
            end
        end
    end
end

rootpool{1} = 'Documents';
rootpool{2} = './Documents';
rootpool{3} = '/Users/huaxinxu/Documents';
for iroot = 1:length(rootpool)
    root = rootpool{iroot};
    for imodel = 1:length(modelpool)
        model = modelpool{imodel};
        [r1,r2] = u_setspecdir(root,model);
        if 1==strcmp(model,'nonexist') ...
            || 1==strcmp(model,'./nonexist') ...
            || 1==strcmp(model,'normal') ...
            || 1==strcmp(model, '/Users/huaxinxu/Downloads') ...
            || 1==strcmp(model, '/Users/huaxinxu/Documents/MATLAB') ...
            || 1==strcmp(model, './MATLAB')
            if ~isempty(r1) || ~isempty(r2)
                error('Wrong! root = ''%s'' ', root);
            end
        end
        
        if 1==strcmp(model,'MATLAB')             
            b = '/Users/huaxinxu/Documents/MATLAB';
            [~,c,~]=fileparts(b);
            if 1~=strcmp(r1,b) || 1~=strcmp(r2,c)
                error('Wrong! root = ''%s'', model = ''%s'' ', root, model);
            end
        end
    end
end

cd(a);
